% Initialization file for demo ssc_lithium_cell_1RC_estim_ini.mdl. Demo
% based on T. Huria, M. Ceraolo, J. Gazzarri, R. Jackey. "High Fidelity
% Electrical Model with Thermal Dependence for Characterization and
% Simulation of High Power Lithium Battery Cells," IEEE International
% Electric Vehicle Conference, March 2012
%
% Copyright 2012 The MathWorks, Inc.


%% Chosen Values

% SOC Lookup Table breakpoints
SOC_LUT = (0:0.05:1)';


%% Known Values

% Battery capacity
% Measured by coulomb counting the discharge curve
Capacity = 100; %Ampere*hours

% Charge deficit at start of data set
% Assumption based on preparation of test
Qe_init = 0; %Ampere*hours


%% Estimated Parameters - Initial starting points before estimation

% Em open-circuit voltage vs SOC
Em = 118*ones(size(SOC_LUT)); %Volts
% R0 resistance vs SOC
R0 = 0.01*ones(size(SOC_LUT)); %Ohms
% R Resistance vs SOC
R1 = 0.0005*ones(size(SOC_LUT)); %Ohms
R2=0.0005*ones(size(SOC_LUT));
R3=0.0005*ones(size(SOC_LUT));
% C Capacitance vs SOC
C1 = 10*ones(size(SOC_LUT)); %Farads
C2=100*ones(size(SOC_LUT));
C3=500*ones(size(SOC_LUT));






%% Load Dataset
load('SumsungData.mat')

%% Samsung Battery Pack Parameters
% Samsung Battery 94 Ah Datasheet Block Parameters
Em_s=[4.238 4.146 4.083 4.024 3.968 3.917 3.869 3.823 3.778 3.736 3.687 3.649 3.628 3.611 3.593 3.574 3.542 3.496 3.438 3.401 3.266]';
SOC_Brkpoints_s=(0:0.05:1)';

T_LUT_s=[-25 -10 0 10 25 40]+273.15;
SOC_Resistance_Brkpoints_s= [0.1 0.2 0.3 0.4 0.5 0.6 0.7 0.8 0.9];

R_battery_Discharging_30=[53.49 	20.28 	11.06 	9.70 	9.34 	9.45 	9.30 	9.29 	9.43; 
22.72 	9.23 	5.53 	5.06 	4.90 	4.92 	4.85 	4.84 	4.90; 
12.46 	5.67 	3.73 	3.42 	3.31 	3.41 	3.36 	3.35 	3.40;
6.59 	3.91 	2.73 	2.51 	2.46 	2.55 	2.54 	2.50 	2.60; 
3.68 	2.73 	1.94 	1.78 	1.77 	1.85 	1.86 	1.88 	1.91; 
2.47 	1.77 	1.53 	1.52 	1.40 	1.49 	1.54 	1.55 	1.57].*10^-3;

R_battery_Charging_30=[26.33 	22.68 	20.78 	19.52 	19.88 	19.41 	19.43 	19.22 	22.19;
9.74 	8.08 	7.34 	7.18 	7.40 	7.33 	7.36 	7.46 	7.57; 
5.51 	4.53 	4.10 	4.03 	4.29 	4.24 	4.25 	4.27 	4.35; 
3.31 	2.87 	2.60 	2.51 	2.71 	2.71 	2.70 	2.73 	2.80; 
2.05 	1.90 	1.68 	1.64 	1.83 	1.81 	1.82 	1.85 	1.87;
1.60 	1.57 	1.39 	1.34 	1.47 	1.48 	1.48 	1.51 	1.51].*10^-3;

% Cell dimensions and sizes
cell_thickness_s = 26.5*10^-3; %m
cell_width_s = 91*10^-3; %m
cell_length_s = 148*10^-3; %m

% Cell volume
samsung_cell_volume = cell_thickness_s*cell_width_s*cell_length_s; %m^3

% Cell mass
samsung_cell_mass = 0.875; %kg

% Volumetric heat capacity
% assumes uniform heat capacity throughout the cell
% ref: J. Electrochemical Society 158 (8) A955-A969 (2011) pA962
cell_rho_Cp = 2.04E6; %J/m3/K

%Specific Heat
samsung_Cp_heat = (cell_rho_Cp * samsung_cell_volume)/samsung_cell_mass; %J/kg/K
%cells in series/parallel
Ns_s=28;
Np_s=2;
% Pack Mass
m_s=samsung_cell_mass*Ns_s*Np_s ; %Kg
C_b_s=m_s*samsung_Cp_heat; % Before it was: C_b_s=m_s*samsung_Cp_heat;
Qe_init_s = 0; %Ampere*hours

Nominal_Capacity_s=50;
Initial_Capacity=50;

        